@@ -43,6 +43,7 @@ __all__ = (
     "DominantLanguageTypeDef",
     "EndpointPropertiesTypeDef",
     "EntitiesDetectionJobPropertiesTypeDef",
+    "EntityLabelTypeDef",
     "EntityRecognizerAnnotationsTypeDef",
     "EntityRecognizerDocumentsTypeDef",
     "EntityRecognizerEntityListTypeDef",
@@ -76,6 +77,7 @@ __all__ = (
     "BatchDetectSentimentResponseTypeDef",
     "BatchDetectSyntaxResponseTypeDef",
     "ClassifyDocumentResponseTypeDef",
+    "ContainsPiiEntitiesResponseTypeDef",
     "CreateDocumentClassifierResponseTypeDef",
     "CreateEndpointResponseTypeDef",
     "CreateEntityRecognizerResponseTypeDef",
@@ -333,6 +335,39 @@ EntitiesDetectionJobPropertiesTypeDef = TypedDict(
     total=False,
 )
 
+EntityLabelTypeDef = TypedDict(
+    "EntityLabelTypeDef",
+    {
+        "Name": Literal[
+            "BANK_ACCOUNT_NUMBER",
+            "BANK_ROUTING",
+            "CREDIT_DEBIT_NUMBER",
+            "CREDIT_DEBIT_CVV",
+            "CREDIT_DEBIT_EXPIRY",
+            "PIN",
+            "EMAIL",
+            "ADDRESS",
+            "NAME",
+            "PHONE",
+            "SSN",
+            "DATE_TIME",
+            "PASSPORT_NUMBER",
+            "DRIVER_ID",
+            "URL",
+            "AGE",
+            "USERNAME",
+            "PASSWORD",
+            "AWS_ACCESS_KEY",
+            "AWS_SECRET_KEY",
+            "IP_ADDRESS",
+            "MAC_ADDRESS",
+            "ALL",
+        ],
+        "Score": float,
+    },
+    total=False,
+)
+
 EntityRecognizerAnnotationsTypeDef = TypedDict("EntityRecognizerAnnotationsTypeDef", {"S3Uri": str})
 
 EntityRecognizerDocumentsTypeDef = TypedDict("EntityRecognizerDocumentsTypeDef", {"S3Uri": str})
@@ -772,6 +807,10 @@ ClassifyDocumentResponseTypeDef = TypedDict(
     total=False,
 )
 
+ContainsPiiEntitiesResponseTypeDef = TypedDict(
+    "ContainsPiiEntitiesResponseTypeDef", {"Labels": List["EntityLabelTypeDef"]}, total=False
+)
+
 CreateDocumentClassifierResponseTypeDef = TypedDict(
     "CreateDocumentClassifierResponseTypeDef", {"DocumentClassifierArn": str}, total=False
 )
